/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2013-2023 Chaosdorf e.V.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package de.chaosdorf.meteroid.ui.navigation

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.draw.shadow
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import coil.compose.AsyncImage
import de.chaosdorf.meteroid.model.Server
import de.chaosdorf.meteroid.model.User

@Composable
fun MeteroidTopBar(
  account: Pair<Server, User?>?,
  onNavigate: (String) -> Unit = {}
) {
  TopAppBar(
    title = {
      Text(
        account?.second?.name
          ?: account?.first?.name
          ?: "Meteroid"
      )
    },
    navigationIcon = {
      AsyncImage(
        account?.second?.gravatarUrl(),
        contentDescription = "User List",
        contentScale = ContentScale.Crop,
        modifier = Modifier
          .size(48.dp)
          .clip(CircleShape)
          .border(1.dp, Color.White, CircleShape)
          .background(MaterialTheme.colorScheme.primaryContainer)
      )
    },
    actions = {
      account?.second?.let { user ->
        val (foreground, background) =
          if (user.balance < 0)
            Pair(MaterialTheme.colorScheme.onError, MaterialTheme.colorScheme.error)
          else
            Pair(MaterialTheme.colorScheme.onPrimary, MaterialTheme.colorScheme.primary)

        Text(
          String.format("%.02f €", user.balance),
          color = foreground,
          fontSize = 14.sp,
          lineHeight = 20.sp,
          fontWeight = FontWeight.SemiBold,
          modifier = Modifier
            .padding(end = 20.dp)
            .clip(RoundedCornerShape(16.dp))
            .background(background)
            .padding(horizontal = 8.dp)
        )
      }
    },
    modifier = Modifier
      .shadow(4.dp)
      .clickable { onNavigate(Routes.Users.Root) }
  )
}
